@@ -16,21 +16,21 @@
 
 from os import path
 import os
-from calculate.lib.datavars import ReadonlyVariable
-from calculate.lib.utils.common import (getValueFromCmdLine, getXorgConfContent,
+from ..datavars import ReadonlyVariable
+from ..utils.common import (getValueFromCmdLine, getXorgConfContent,
                                         getValueFromConfig, CmdlineParams)
-from calculate.lib.utils.format import XorgConfig
+from ..utils.format import XorgConfig
 from collections import OrderedDict
 
 import sys
-from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
+from ..cl_lang import setLocalTranslate, getLazyLocalTranslate
 
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
 
 __ = getLazyLocalTranslate(_)
 
-class Locale(object):
+class Locale():
     # http://www.localeplanet.com/icu/
     langData = OrderedDict([
         ('be_BY', {
@@ -477,7 +477,8 @@ class Locale(object):
 
     default_lang = "en_US"
 
-    fields = list(langData[default_lang].keys())
+    #first list for casting, second one for list in list
+    fields = list(list(langData[default_lang].keys()))
     
     aliases = {
         'en_AU': 'en_US',
@@ -486,22 +487,21 @@ class Locale(object):
     }
 
     def getLangs(self):
-        return self.langData.keys()
+        return list(self.langData.keys())
 
     def getKeyboardLayouts(self):
         skip = self.aliases.keys()
         return [x for x in self.langData.keys() if x not in skip]
 
     def getLanguages(self):
-        return map(lambda x: self.langData[x]['language'],
-                   self.langData.keys())
+        return [self.langData[x]['language'] for x in self.langData.keys()]
 
     def isLangExists(self, lang):
         return lang in self.langData.keys()
 
     def isValueInFieldExists(self, field, value):
-        return value in map(lambda x: self.langData[x][field],
-                            self.langData.keys())
+        return value in (self.langData[x][field] for x in self.langData.keys())
+
 
     def getFields(self, field):
         return [l[1][field] for l in self.langData.items()]
@@ -522,6 +522,7 @@ class Locale(object):
             raise AttributeError("getLang: wrong field")
         return self.getLangByField(field, kw[field])
 
+
     def getKeyboardLayout(self, **kw):
         if "lang" in kw:
             if kw["lang"] in self.langData:
@@ -544,18 +545,7 @@ class Locale(object):
                 return wrapper
         raise AttributeError("'Locale' object has no attribute '%s'" % attrname)
 
-    def getLang(self, **kw):
-        """
-        Получить язык по указанному полю.
 
-        getLang(keymap="ua-utf")
-        """
-        if not kw:
-            raise AttributeError("getLang: field missed")
-        field = next(iter(kw.keys()))
-        if field not in self.fields:
-            raise AttributeError("getLang: wrong field")
-        return self.getLangByField(field, kw[field])
 
     def __getattr__(self, attrname):
         """
@@ -765,7 +755,7 @@ class VariableOsLang(ReadonlyVariable, Locale):
         return self.getLangs()
 
     def humanReadable(self):
-        return map(lambda x: self.getName(x), self.Get())
+        return [self.getName(x) for x in self.Get()]
 
 class VariableOsKeyboardLayout(ReadonlyVariable, Locale):
     """
@@ -777,4 +767,4 @@ class VariableOsKeyboardLayout(ReadonlyVariable, Locale):
         return self.getKeyboardLayouts()
 
     def humanReadable(self):
-        return map(lambda x: self.getLayoutname(x), self.Get())
+        return [self.getLayoutname(x) for x in self.Get()]
